pub enum Error {
FailedToOpen,
Unspecified,
Allocate,
DecInput,
EnoughMem,
Parameter,
NotSupported,
RestartRequired,
Cpu,
TryAgain,
Eof,
Unknown(i32),
}Expand description
An error that has occurred in VVdeC.
Variants
FailedToOpen
Failed to open decoder.
Unspecified
Unspecified malfunction.
Allocate
Internal allocation error.
DecInput
Decoder input error.
EnoughMem
Allocated memory too small to receive decoded data. After allocating sufficient memory the failed call can be repeated.
Parameter
Inconsistent or invalid parameters.
NotSupported
Unsupported request.
RestartRequired
Decoder requires restart.
Cpu
Unsupported CPU.
TryAgain
Decoder needs more input and cannot return a picture.
Eof
End of file.
Unknown(i32)
Unknown error.