AccessUnit

Struct AccessUnit 

pub struct AccessUnit<A> {
    pub payload: A,
    pub cts: Option<u64>,
    pub dts: Option<u64>,
    pub is_random_access_point: bool,
}
Access unit containing VVC bitstream data.

VVdeC expects that the pushed access units follow the Annex-B format - prefixed by 0x000001 or 0x00000001.

Fields

payload: A

The payload data.

cts: Option<u64>

Composition timestamp.

The composition timestamp is not used by VVdeC and is passed unchanged to the corresponding decoded Frame object. It can be used to transport arbitrary frame identifiers, if necessary by your application.

dts: Option<u64>

Decoding timestamp.

is_random_access_point: bool

Is it an random access point?

Implementations

Source

impl<A> AccessUnit<A>

pub fn new(payload: A) -> Self

Create a new access unit with no cts or dts, that is also not a random access point.